/*===- TableGen'erated file -------------------------------------*- C++ -*-===*\
|*                                                                            *|
|* List of builtins that Clang recognizes                                     *|
|*                                                                            *|
|* Automatically generated file, do not edit!                                 *|
|*                                                                            *|
\*===----------------------------------------------------------------------===*/


#ifdef GET_BUILTIN_ENUMERATORS
    BI__builtin_riscv_aes32dsi,
    BI__builtin_riscv_aes32dsmi,
    BI__builtin_riscv_aes32esi,
    BI__builtin_riscv_aes32esmi,
    BI__builtin_riscv_aes64ds,
    BI__builtin_riscv_aes64dsm,
    BI__builtin_riscv_aes64es,
    BI__builtin_riscv_aes64esm,
    BI__builtin_riscv_aes64im,
    BI__builtin_riscv_aes64ks1i,
    BI__builtin_riscv_aes64ks2,
    BI__builtin_riscv_cv_alu_addN,
    BI__builtin_riscv_cv_alu_addRN,
    BI__builtin_riscv_cv_alu_adduN,
    BI__builtin_riscv_cv_alu_adduRN,
    BI__builtin_riscv_cv_alu_clip,
    BI__builtin_riscv_cv_alu_clipu,
    BI__builtin_riscv_cv_alu_extbs,
    BI__builtin_riscv_cv_alu_extbz,
    BI__builtin_riscv_cv_alu_exths,
    BI__builtin_riscv_cv_alu_exthz,
    BI__builtin_riscv_cv_alu_sle,
    BI__builtin_riscv_cv_alu_sleu,
    BI__builtin_riscv_cv_alu_subN,
    BI__builtin_riscv_cv_alu_subRN,
    BI__builtin_riscv_cv_alu_subuN,
    BI__builtin_riscv_cv_alu_subuRN,
    BI__builtin_riscv_brev8_32,
    BI__builtin_riscv_brev8_64,
    BI__builtin_riscv_clmul_32,
    BI__builtin_riscv_clmul_64,
    BI__builtin_riscv_clmulh_32,
    BI__builtin_riscv_clmulh_64,
    BI__builtin_riscv_clmulr_32,
    BI__builtin_riscv_clmulr_64,
    BI__builtin_riscv_clz_32,
    BI__builtin_riscv_clz_64,
    BI__builtin_riscv_ctz_32,
    BI__builtin_riscv_ctz_64,
    BI__builtin_riscv_nds_fcvt_bf16_s,
    BI__builtin_riscv_nds_fcvt_s_bf16,
    BI__builtin_riscv_nds_ffb_32,
    BI__builtin_riscv_nds_ffb_64,
    BI__builtin_riscv_nds_ffmism_32,
    BI__builtin_riscv_nds_ffmism_64,
    BI__builtin_riscv_nds_ffzmism_32,
    BI__builtin_riscv_nds_ffzmism_64,
    BI__builtin_riscv_nds_flmism_32,
    BI__builtin_riscv_nds_flmism_64,
    BI__builtin_riscv_mips_ehb,
    BI__builtin_riscv_mips_ihb,
    BI__builtin_riscv_mips_pause,
    BI__builtin_riscv_ntl_load,
    BI__builtin_riscv_ntl_store,
    BI__builtin_riscv_orc_b_32,
    BI__builtin_riscv_orc_b_64,
    BI__builtin_riscv_pause,
    BI__builtin_riscv_sha256sig0,
    BI__builtin_riscv_sha256sig1,
    BI__builtin_riscv_sha256sum0,
    BI__builtin_riscv_sha256sum1,
    BI__builtin_riscv_sha512sig0,
    BI__builtin_riscv_sha512sig0h,
    BI__builtin_riscv_sha512sig0l,
    BI__builtin_riscv_sha512sig1,
    BI__builtin_riscv_sha512sig1h,
    BI__builtin_riscv_sha512sig1l,
    BI__builtin_riscv_sha512sum0,
    BI__builtin_riscv_sha512sum0r,
    BI__builtin_riscv_sha512sum1,
    BI__builtin_riscv_sha512sum1r,
    BI__builtin_riscv_sm3p0,
    BI__builtin_riscv_sm3p1,
    BI__builtin_riscv_sm4ed,
    BI__builtin_riscv_sm4ks,
    BI__builtin_riscv_unzip_32,
    BI__builtin_riscv_xperm4_32,
    BI__builtin_riscv_xperm4_64,
    BI__builtin_riscv_xperm8_32,
    BI__builtin_riscv_xperm8_64,
    BI__builtin_riscv_zip_32,

#endif // GET_BUILTIN_ENUMERATORS

#ifdef GET_BUILTIN_STR_TABLE

#ifdef __GNUC__
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Woverlength-strings"
#endif
static constexpr char BuiltinStringsStorage[] =
  "\0"
  "__builtin_riscv_aes32dsi\0"
  "UiUiUiIUi\0"
  "nc\0"
  "zknd,32bit\0"
  "__builtin_riscv_aes32dsmi\0"
  "__builtin_riscv_aes32esi\0"
  "zkne,32bit\0"
  "__builtin_riscv_aes32esmi\0"
  "__builtin_riscv_aes64ds\0"
  "UWiUWiUWi\0"
  "zknd,64bit\0"
  "__builtin_riscv_aes64dsm\0"
  "__builtin_riscv_aes64es\0"
  "zkne,64bit\0"
  "__builtin_riscv_aes64esm\0"
  "__builtin_riscv_aes64im\0"
  "UWiUWi\0"
  "__builtin_riscv_aes64ks1i\0"
  "UWiUWiIUi\0"
  "zknd|zkne,64bit\0"
  "__builtin_riscv_aes64ks2\0"
  "__builtin_riscv_cv_alu_addN\0"
  "iiiUi\0"
  "xcvalu\0"
  "__builtin_riscv_cv_alu_addRN\0"
  "__builtin_riscv_cv_alu_adduN\0"
  "UiUiUiUi\0"
  "__builtin_riscv_cv_alu_adduRN\0"
  "__builtin_riscv_cv_alu_clip\0"
  "iii\0"
  "__builtin_riscv_cv_alu_clipu\0"
  "UiUiUi\0"
  "__builtin_riscv_cv_alu_extbs\0"
  "ii\0"
  "__builtin_riscv_cv_alu_extbz\0"
  "UiUi\0"
  "__builtin_riscv_cv_alu_exths\0"
  "__builtin_riscv_cv_alu_exthz\0"
  "__builtin_riscv_cv_alu_sle\0"
  "__builtin_riscv_cv_alu_sleu\0"
  "iUiUi\0"
  "__builtin_riscv_cv_alu_subN\0"
  "__builtin_riscv_cv_alu_subRN\0"
  "__builtin_riscv_cv_alu_subuN\0"
  "__builtin_riscv_cv_alu_subuRN\0"
  "__builtin_riscv_brev8_32\0"
  "zbkb\0"
  "__builtin_riscv_brev8_64\0"
  "zbkb,64bit\0"
  "__builtin_riscv_clmul_32\0"
  "zbc|zbkc\0"
  "__builtin_riscv_clmul_64\0"
  "zbc|zbkc,64bit\0"
  "__builtin_riscv_clmulh_32\0"
  "zbc|zbkc,32bit\0"
  "__builtin_riscv_clmulh_64\0"
  "__builtin_riscv_clmulr_32\0"
  "zbc,32bit\0"
  "__builtin_riscv_clmulr_64\0"
  "zbc,64bit\0"
  "__builtin_riscv_clz_32\0"
  "zbb|xtheadbb\0"
  "__builtin_riscv_clz_64\0"
  "UiUWi\0"
  "zbb|xtheadbb,64bit\0"
  "__builtin_riscv_ctz_32\0"
  "zbb\0"
  "__builtin_riscv_ctz_64\0"
  "zbb,64bit\0"
  "__builtin_riscv_nds_fcvt_bf16_s\0"
  "yf\0"
  "xandesbfhcvt\0"
  "__builtin_riscv_nds_fcvt_s_bf16\0"
  "fy\0"
  "__builtin_riscv_nds_ffb_32\0"
  "ZiUZiUZi\0"
  "xandesperf,32bit\0"
  "__builtin_riscv_nds_ffb_64\0"
  "WiUWiUWi\0"
  "xandesperf,64bit\0"
  "__builtin_riscv_nds_ffmism_32\0"
  "__builtin_riscv_nds_ffmism_64\0"
  "__builtin_riscv_nds_ffzmism_32\0"
  "__builtin_riscv_nds_ffzmism_64\0"
  "__builtin_riscv_nds_flmism_32\0"
  "__builtin_riscv_nds_flmism_64\0"
  "__builtin_riscv_mips_ehb\0"
  "v\0"
  "xmipsexectl\0"
  "__builtin_riscv_mips_ihb\0"
  "__builtin_riscv_mips_pause\0"
  "__builtin_riscv_ntl_load\0"
  "v.\0"
  "t\0"
  "zihintntl\0"
  "__builtin_riscv_ntl_store\0"
  "__builtin_riscv_orc_b_32\0"
  "__builtin_riscv_orc_b_64\0"
  "__builtin_riscv_pause\0"
  "n\0"
  "zihintpause\0"
  "__builtin_riscv_sha256sig0\0"
  "zknh\0"
  "__builtin_riscv_sha256sig1\0"
  "__builtin_riscv_sha256sum0\0"
  "__builtin_riscv_sha256sum1\0"
  "__builtin_riscv_sha512sig0\0"
  "zknh,64bit\0"
  "__builtin_riscv_sha512sig0h\0"
  "zknh,32bit\0"
  "__builtin_riscv_sha512sig0l\0"
  "__builtin_riscv_sha512sig1\0"
  "__builtin_riscv_sha512sig1h\0"
  "__builtin_riscv_sha512sig1l\0"
  "__builtin_riscv_sha512sum0\0"
  "__builtin_riscv_sha512sum0r\0"
  "__builtin_riscv_sha512sum1\0"
  "__builtin_riscv_sha512sum1r\0"
  "__builtin_riscv_sm3p0\0"
  "zksh\0"
  "__builtin_riscv_sm3p1\0"
  "__builtin_riscv_sm4ed\0"
  "zksed\0"
  "__builtin_riscv_sm4ks\0"
  "__builtin_riscv_unzip_32\0"
  "zbkb,32bit\0"
  "__builtin_riscv_xperm4_32\0"
  "zbkx,32bit\0"
  "__builtin_riscv_xperm4_64\0"
  "zbkx,64bit\0"
  "__builtin_riscv_xperm8_32\0"
  "__builtin_riscv_xperm8_64\0"
  "__builtin_riscv_zip_32\0"
  ;
#ifdef __GNUC__
#pragma GCC diagnostic pop
#endif

static constexpr llvm::StringTable
BuiltinStrings = BuiltinStringsStorage;

#endif // GET_BUILTIN_STR_TABLE

#ifdef GET_BUILTIN_INFOS
    Builtin::Info{Builtin::Info::StrOffsets{1 /* __builtin_riscv_aes32dsi */, 26 /* UiUiUiIUi */, 36 /* nc */, 39 /* zknd,32bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{50 /* __builtin_riscv_aes32dsmi */, 26 /* UiUiUiIUi */, 36 /* nc */, 39 /* zknd,32bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{76 /* __builtin_riscv_aes32esi */, 26 /* UiUiUiIUi */, 36 /* nc */, 101 /* zkne,32bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{112 /* __builtin_riscv_aes32esmi */, 26 /* UiUiUiIUi */, 36 /* nc */, 101 /* zkne,32bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{138 /* __builtin_riscv_aes64ds */, 162 /* UWiUWiUWi */, 36 /* nc */, 172 /* zknd,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{183 /* __builtin_riscv_aes64dsm */, 162 /* UWiUWiUWi */, 36 /* nc */, 172 /* zknd,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{208 /* __builtin_riscv_aes64es */, 162 /* UWiUWiUWi */, 36 /* nc */, 232 /* zkne,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{243 /* __builtin_riscv_aes64esm */, 162 /* UWiUWiUWi */, 36 /* nc */, 232 /* zkne,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{268 /* __builtin_riscv_aes64im */, 292 /* UWiUWi */, 36 /* nc */, 172 /* zknd,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{299 /* __builtin_riscv_aes64ks1i */, 325 /* UWiUWiIUi */, 36 /* nc */, 335 /* zknd|zkne,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{351 /* __builtin_riscv_aes64ks2 */, 162 /* UWiUWiUWi */, 36 /* nc */, 335 /* zknd|zkne,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{376 /* __builtin_riscv_cv_alu_addN */, 404 /* iiiUi */, 36 /* nc */, 410 /* xcvalu */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{417 /* __builtin_riscv_cv_alu_addRN */, 404 /* iiiUi */, 36 /* nc */, 410 /* xcvalu */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{446 /* __builtin_riscv_cv_alu_adduN */, 475 /* UiUiUiUi */, 36 /* nc */, 410 /* xcvalu */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{484 /* __builtin_riscv_cv_alu_adduRN */, 475 /* UiUiUiUi */, 36 /* nc */, 410 /* xcvalu */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{514 /* __builtin_riscv_cv_alu_clip */, 542 /* iii */, 36 /* nc */, 410 /* xcvalu */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{546 /* __builtin_riscv_cv_alu_clipu */, 575 /* UiUiUi */, 36 /* nc */, 410 /* xcvalu */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{582 /* __builtin_riscv_cv_alu_extbs */, 611 /* ii */, 36 /* nc */, 410 /* xcvalu */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{614 /* __builtin_riscv_cv_alu_extbz */, 643 /* UiUi */, 36 /* nc */, 410 /* xcvalu */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{648 /* __builtin_riscv_cv_alu_exths */, 611 /* ii */, 36 /* nc */, 410 /* xcvalu */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{677 /* __builtin_riscv_cv_alu_exthz */, 643 /* UiUi */, 36 /* nc */, 410 /* xcvalu */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{706 /* __builtin_riscv_cv_alu_sle */, 542 /* iii */, 36 /* nc */, 410 /* xcvalu */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{733 /* __builtin_riscv_cv_alu_sleu */, 761 /* iUiUi */, 36 /* nc */, 410 /* xcvalu */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{767 /* __builtin_riscv_cv_alu_subN */, 404 /* iiiUi */, 36 /* nc */, 410 /* xcvalu */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{795 /* __builtin_riscv_cv_alu_subRN */, 404 /* iiiUi */, 36 /* nc */, 410 /* xcvalu */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{824 /* __builtin_riscv_cv_alu_subuN */, 475 /* UiUiUiUi */, 36 /* nc */, 410 /* xcvalu */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{853 /* __builtin_riscv_cv_alu_subuRN */, 475 /* UiUiUiUi */, 36 /* nc */, 410 /* xcvalu */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{883 /* __builtin_riscv_brev8_32 */, 643 /* UiUi */, 36 /* nc */, 908 /* zbkb */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{913 /* __builtin_riscv_brev8_64 */, 292 /* UWiUWi */, 36 /* nc */, 938 /* zbkb,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{949 /* __builtin_riscv_clmul_32 */, 575 /* UiUiUi */, 36 /* nc */, 974 /* zbc|zbkc */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{983 /* __builtin_riscv_clmul_64 */, 162 /* UWiUWiUWi */, 36 /* nc */, 1008 /* zbc|zbkc,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1023 /* __builtin_riscv_clmulh_32 */, 575 /* UiUiUi */, 36 /* nc */, 1049 /* zbc|zbkc,32bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1064 /* __builtin_riscv_clmulh_64 */, 162 /* UWiUWiUWi */, 36 /* nc */, 1008 /* zbc|zbkc,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1090 /* __builtin_riscv_clmulr_32 */, 575 /* UiUiUi */, 36 /* nc */, 1116 /* zbc,32bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1126 /* __builtin_riscv_clmulr_64 */, 162 /* UWiUWiUWi */, 36 /* nc */, 1152 /* zbc,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1162 /* __builtin_riscv_clz_32 */, 643 /* UiUi */, 36 /* nc */, 1185 /* zbb|xtheadbb */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1198 /* __builtin_riscv_clz_64 */, 1221 /* UiUWi */, 36 /* nc */, 1227 /* zbb|xtheadbb,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1246 /* __builtin_riscv_ctz_32 */, 643 /* UiUi */, 36 /* nc */, 1269 /* zbb */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1273 /* __builtin_riscv_ctz_64 */, 1221 /* UiUWi */, 36 /* nc */, 1296 /* zbb,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1306 /* __builtin_riscv_nds_fcvt_bf16_s */, 1338 /* yf */, 36 /* nc */, 1341 /* xandesbfhcvt */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1354 /* __builtin_riscv_nds_fcvt_s_bf16 */, 1386 /* fy */, 36 /* nc */, 1341 /* xandesbfhcvt */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1389 /* __builtin_riscv_nds_ffb_32 */, 1416 /* ZiUZiUZi */, 36 /* nc */, 1425 /* xandesperf,32bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1442 /* __builtin_riscv_nds_ffb_64 */, 1469 /* WiUWiUWi */, 36 /* nc */, 1478 /* xandesperf,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1495 /* __builtin_riscv_nds_ffmism_32 */, 1416 /* ZiUZiUZi */, 36 /* nc */, 1425 /* xandesperf,32bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1525 /* __builtin_riscv_nds_ffmism_64 */, 1469 /* WiUWiUWi */, 36 /* nc */, 1478 /* xandesperf,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1555 /* __builtin_riscv_nds_ffzmism_32 */, 1416 /* ZiUZiUZi */, 36 /* nc */, 1425 /* xandesperf,32bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1586 /* __builtin_riscv_nds_ffzmism_64 */, 1469 /* WiUWiUWi */, 36 /* nc */, 1478 /* xandesperf,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1617 /* __builtin_riscv_nds_flmism_32 */, 1416 /* ZiUZiUZi */, 36 /* nc */, 1425 /* xandesperf,32bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1647 /* __builtin_riscv_nds_flmism_64 */, 1469 /* WiUWiUWi */, 36 /* nc */, 1478 /* xandesperf,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1677 /* __builtin_riscv_mips_ehb */, 1702 /* v */, 36 /* nc */, 1704 /* xmipsexectl */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1716 /* __builtin_riscv_mips_ihb */, 1702 /* v */, 36 /* nc */, 1704 /* xmipsexectl */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1741 /* __builtin_riscv_mips_pause */, 1702 /* v */, 36 /* nc */, 1704 /* xmipsexectl */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1768 /* __builtin_riscv_ntl_load */, 1793 /* v. */, 1796 /* t */, 1798 /* zihintntl */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1808 /* __builtin_riscv_ntl_store */, 1793 /* v. */, 1796 /* t */, 1798 /* zihintntl */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1834 /* __builtin_riscv_orc_b_32 */, 643 /* UiUi */, 36 /* nc */, 1269 /* zbb */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1859 /* __builtin_riscv_orc_b_64 */, 292 /* UWiUWi */, 36 /* nc */, 1296 /* zbb,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1884 /* __builtin_riscv_pause */, 1702 /* v */, 1906 /* n */, 1908 /* zihintpause */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1920 /* __builtin_riscv_sha256sig0 */, 643 /* UiUi */, 36 /* nc */, 1947 /* zknh */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1952 /* __builtin_riscv_sha256sig1 */, 643 /* UiUi */, 36 /* nc */, 1947 /* zknh */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{1979 /* __builtin_riscv_sha256sum0 */, 643 /* UiUi */, 36 /* nc */, 1947 /* zknh */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{2006 /* __builtin_riscv_sha256sum1 */, 643 /* UiUi */, 36 /* nc */, 1947 /* zknh */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{2033 /* __builtin_riscv_sha512sig0 */, 292 /* UWiUWi */, 36 /* nc */, 2060 /* zknh,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{2071 /* __builtin_riscv_sha512sig0h */, 575 /* UiUiUi */, 36 /* nc */, 2099 /* zknh,32bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{2110 /* __builtin_riscv_sha512sig0l */, 575 /* UiUiUi */, 36 /* nc */, 2099 /* zknh,32bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{2138 /* __builtin_riscv_sha512sig1 */, 292 /* UWiUWi */, 36 /* nc */, 2060 /* zknh,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{2165 /* __builtin_riscv_sha512sig1h */, 575 /* UiUiUi */, 36 /* nc */, 2099 /* zknh,32bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{2193 /* __builtin_riscv_sha512sig1l */, 575 /* UiUiUi */, 36 /* nc */, 2099 /* zknh,32bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{2221 /* __builtin_riscv_sha512sum0 */, 292 /* UWiUWi */, 36 /* nc */, 2060 /* zknh,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{2248 /* __builtin_riscv_sha512sum0r */, 575 /* UiUiUi */, 36 /* nc */, 2099 /* zknh,32bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{2276 /* __builtin_riscv_sha512sum1 */, 292 /* UWiUWi */, 36 /* nc */, 2060 /* zknh,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{2303 /* __builtin_riscv_sha512sum1r */, 575 /* UiUiUi */, 36 /* nc */, 2099 /* zknh,32bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{2331 /* __builtin_riscv_sm3p0 */, 643 /* UiUi */, 36 /* nc */, 2353 /* zksh */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{2358 /* __builtin_riscv_sm3p1 */, 643 /* UiUi */, 36 /* nc */, 2353 /* zksh */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{2380 /* __builtin_riscv_sm4ed */, 26 /* UiUiUiIUi */, 36 /* nc */, 2402 /* zksed */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{2408 /* __builtin_riscv_sm4ks */, 26 /* UiUiUiIUi */, 36 /* nc */, 2402 /* zksed */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{2430 /* __builtin_riscv_unzip_32 */, 643 /* UiUi */, 36 /* nc */, 2455 /* zbkb,32bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{2466 /* __builtin_riscv_xperm4_32 */, 575 /* UiUiUi */, 36 /* nc */, 2492 /* zbkx,32bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{2503 /* __builtin_riscv_xperm4_64 */, 162 /* UWiUWiUWi */, 36 /* nc */, 2529 /* zbkx,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{2540 /* __builtin_riscv_xperm8_32 */, 575 /* UiUiUi */, 36 /* nc */, 2492 /* zbkx,32bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{2566 /* __builtin_riscv_xperm8_64 */, 162 /* UWiUWiUWi */, 36 /* nc */, 2529 /* zbkx,64bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},
    Builtin::Info{Builtin::Info::StrOffsets{2592 /* __builtin_riscv_zip_32 */, 643 /* UiUi */, 36 /* nc */, 2455 /* zbkb,32bit */}, HeaderDesc::NO_HEADER, ALL_LANGUAGES},

#endif // GET_BUILTIN_INFOS

#ifdef GET_BUILTIN_PREFIXED_INFOS

#endif // GET_BUILTIN_PREFIXED_INFOS

#ifdef ATOMIC_BUILTIN

#endif // ATOMIC_BUILTIN
#undef ATOMIC_BUILTIN
